@@ -5,7 +5,7 @@ from uuid import uuid4
 
 import factory
 
-from openedx_ledger.models import Ledger, Transaction, TransactionStateChoices, UnitChoices
+from openedx_ledger.models import Ledger, Reversal, Transaction, TransactionStateChoices, UnitChoices
 
 
 class LedgerFactory(factory.django.DjangoModelFactory):
@@ -35,3 +35,17 @@ class TransactionFactory(factory.django.DjangoModelFactory):
     quantity = factory.Faker("random_int", min=-100000, max=-100)
     ledger = factory.Iterator(Ledger.objects.all())
     lms_user_id = factory.Faker("random_int", min=1, max=1000)
+
+
+class ReversalFactory(factory.django.DjangoModelFactory):
+    """
+    Test factory for the `Reversal` model.
+    """
+    class Meta:
+        model = Reversal
+
+    uuid = factory.LazyFunction(uuid4)
+    transaction = factory.Iterator(Transaction.objects.all())
+    idempotency_key = factory.LazyFunction(uuid4)
+    state = TransactionStateChoices.CREATED
+    quantity = factory.Faker("random_int", min=100, max=10000)
